NAME = "NAME"
COLOR = "NAME/COLOR"
COLOR_OTHER = "NAME/COLOR/COLOR_OTHER"
NATURE_COLOR = "NAME/COLOR/NATURE_COLOR"
DISEASE = "NAME/DISEASE"
ANIMAL_DISEASE = "NAME/DISEASE/ANIMAL_DISEASE"
DISEASE_OTHER = "NAME/DISEASE/DISEASE_OTHER"
EVENT = "NAME/EVENT"
EVENT_OTHER = "NAME/EVENT/EVENT_OTHER"
INCIDENT = "NAME/EVENT/INCIDENT"
INCIDENT_OTHER = "NAME/EVENT/INCIDENT/INCIDENT_OTHER"
WAR = "NAME/EVENT/INCIDENT/WAR"
NATURAL_PHENOMENON = "NAME/EVENT/NATURAL_PHENOMENON"
EARTHQUAKE = "NAME/EVENT/NATURAL_PHENOMENON/EARTHQUAKE"
NATURAL_DISASTER = "NAME/EVENT/NATURAL_PHENOMENON/NATURAL_DISASTER"
NATURAL_PHENOMENON_OTHER = "NAME/EVENT/NATURAL_PHENOMENON/NATURAL_PHENOMENON_OTHER"
OCCASION = "NAME/EVENT/OCCASION"
CONFERENCE = "NAME/EVENT/OCCASION/CONFERENCE"
GAME = "NAME/EVENT/OCCASION/GAME"
OCCASION_OTHER = "NAME/EVENT/OCCASION/OCCASION_OTHER"
RELIGIOUS_FESTIVAL = "NAME/EVENT/OCCASION/RELIGIOUS_FESTIVAL"
FACILITY = "NAME/FACILITY"
ARCHAEOLOGICAL_PLACE = "NAME/FACILITY/ARCHAEOLOGICAL_PLACE"
ARCHAEOLOGICAL_PLACE_OTHER = (
    "NAME/FACILITY/ARCHAEOLOGICAL_PLACE/ARCHAEOLOGICAL_PLACE_OTHER"
)
TUMULUS = "NAME/FACILITY/ARCHAEOLOGICAL_PLACE/TUMULUS"
FACILITY_OTHER = "NAME/FACILITY/FACILITY_OTHER"
FACILITY_PART = "NAME/FACILITY/FACILITY_PART"
GOE = "NAME/FACILITY/GOE"
AIRPORT = "NAME/FACILITY/GOE/AIRPORT"
AMUSEMENT_PARK = "NAME/FACILITY/GOE/AMUSEMENT_PARK"
CAR_STOP = "NAME/FACILITY/GOE/CAR_STOP"
GOE_OTHER = "NAME/FACILITY/GOE/GOE_OTHER"
MARKET = "NAME/FACILITY/GOE/MARKET"
MUSEUM = "NAME/FACILITY/GOE/MUSEUM"
PARK = "NAME/FACILITY/GOE/PARK"
PORT = "NAME/FACILITY/GOE/PORT"
PUBLIC_INSTITUTION = "NAME/FACILITY/GOE/PUBLIC_INSTITUTION"
RESEARCH_INSTITUTE = "NAME/FACILITY/GOE/RESEARCH_INSTITUTE"
SCHOOL = "NAME/FACILITY/GOE/SCHOOL"
SPORTS_FACILITY = "NAME/FACILITY/GOE/SPORTS_FACILITY"
STATION = "NAME/FACILITY/GOE/STATION"
THEATER = "NAME/FACILITY/GOE/THEATER"
WORSHIP_PLACE = "NAME/FACILITY/GOE/WORSHIP_PLACE"
ZOO = "NAME/FACILITY/GOE/ZOO"
LINE = "NAME/FACILITY/LINE"
BRIDGE = "NAME/FACILITY/LINE/BRIDGE"
CANAL = "NAME/FACILITY/LINE/CANAL"
LINE_OTHER = "NAME/FACILITY/LINE/LINE_OTHER"
RAILROAD = "NAME/FACILITY/LINE/RAILROAD"
ROAD = "NAME/FACILITY/LINE/ROAD"
TUNNEL = "NAME/FACILITY/LINE/TUNNEL"
WATER_ROUTE = "NAME/FACILITY/LINE/WATER_ROUTE"
GOD = "NAME/GOD"
LOCATION = "NAME/LOCATION"
ADDRESS = "NAME/LOCATION/ADDRESS"
ADDRESS_OTHER = "NAME/LOCATION/ADDRESS/ADDRESS_OTHER"
EMAIL = "NAME/LOCATION/ADDRESS/EMAIL"
PHONE_NUMBER = "NAME/LOCATION/ADDRESS/PHONE_NUMBER"
POSTAL_ADDRESS = "NAME/LOCATION/ADDRESS/POSTAL_ADDRESS"
URL = "NAME/LOCATION/ADDRESS/URL"
ASTRAL_BODY = "NAME/LOCATION/ASTRAL_BODY"
ASTRAL_BODY_OTHER = "NAME/LOCATION/ASTRAL_BODY/ASTRAL_BODY_OTHER"
CONSTELLATION = "NAME/LOCATION/ASTRAL_BODY/CONSTELLATION"
PLANET = "NAME/LOCATION/ASTRAL_BODY/PLANET"
STAR = "NAME/LOCATION/ASTRAL_BODY/STAR"
GEOLOGICAL_REGION = "NAME/LOCATION/GEOLOGICAL_REGION"
BAY = "NAME/LOCATION/GEOLOGICAL_REGION/BAY"
GEOLOGICAL_REGION_OTHER = "NAME/LOCATION/GEOLOGICAL_REGION/GEOLOGICAL_REGION_OTHER"
ISLAND = "NAME/LOCATION/GEOLOGICAL_REGION/ISLAND"
LAKE = "NAME/LOCATION/GEOLOGICAL_REGION/LAKE"
MOUNTAIN = "NAME/LOCATION/GEOLOGICAL_REGION/MOUNTAIN"
RIVER = "NAME/LOCATION/GEOLOGICAL_REGION/RIVER"
SEA = "NAME/LOCATION/GEOLOGICAL_REGION/SEA"
GPE = "NAME/LOCATION/GPE"
CITY = "NAME/LOCATION/GPE/CITY"
COUNTRY = "NAME/LOCATION/GPE/COUNTRY"
COUNTY = "NAME/LOCATION/GPE/COUNTY"
GPE_OTHER = "NAME/LOCATION/GPE/GPE_OTHER"
PROVINCE = "NAME/LOCATION/GPE/PROVINCE"
LOCATION_OTHER = "NAME/LOCATION/LOCATION_OTHER"
REGION = "NAME/LOCATION/REGION"
CONTINENTAL_REGION = "NAME/LOCATION/REGION/CONTINENTAL_REGION"
DOMESTIC_REGION = "NAME/LOCATION/REGION/DOMESTIC_REGION"
REGION_OTHER = "NAME/LOCATION/REGION/REGION_OTHER"
SPA = "NAME/LOCATION/SPA"
NAME_OTHER = "NAME/NAME_OTHER"
NATURAL_OBJECT = "NAME/NATURAL_OBJECT"
COMPOUND = "NAME/NATURAL_OBJECT/COMPOUND"
ELEMENT = "NAME/NATURAL_OBJECT/ELEMENT"
LIVING_THING = "NAME/NATURAL_OBJECT/LIVING_THING"
AMPHIBIA = "NAME/NATURAL_OBJECT/LIVING_THING/AMPHIBIA"
BIRD = "NAME/NATURAL_OBJECT/LIVING_THING/BIRD"
FISH = "NAME/NATURAL_OBJECT/LIVING_THING/FISH"
FLORA = "NAME/NATURAL_OBJECT/LIVING_THING/FLORA"
FUNGUS = "NAME/NATURAL_OBJECT/LIVING_THING/FUNGUS"
INSECT = "NAME/NATURAL_OBJECT/LIVING_THING/INSECT"
LIVING_THING_OTHER = "NAME/NATURAL_OBJECT/LIVING_THING/LIVING_THING_OTHER"
MAMMAL = "NAME/NATURAL_OBJECT/LIVING_THING/MAMMAL"
MOLLUSC_ARTHROPOD = "NAME/NATURAL_OBJECT/LIVING_THING/MOLLUSC_ARTHROPOD"
REPTILE = "NAME/NATURAL_OBJECT/LIVING_THING/REPTILE"
LIVING_THING_PART = "NAME/NATURAL_OBJECT/LIVING_THING_PART"
ANIMAL_PART = "NAME/NATURAL_OBJECT/LIVING_THING_PART/ANIMAL_PART"
FLORA_PART = "NAME/NATURAL_OBJECT/LIVING_THING_PART/FLORA_PART"
LIVING_THING_PART_OTHER = (
    "NAME/NATURAL_OBJECT/LIVING_THING_PART/LIVING_THING_PART_OTHER"
)
MINERAL = "NAME/NATURAL_OBJECT/MINERAL"
NATURAL_OBJECT_OTHER = "NAME/NATURAL_OBJECT/NATURAL_OBJECT_OTHER"
ORGANIZATION = "NAME/ORGANIZATION"
CORPORATION = "NAME/ORGANIZATION/CORPORATION"
COMPANY = "NAME/ORGANIZATION/CORPORATION/COMPANY"
COMPANY_GROUP = "NAME/ORGANIZATION/CORPORATION/COMPANY_GROUP"
CORPORATION_OTHER = "NAME/ORGANIZATION/CORPORATION/CORPORATION_OTHER"
ETHNIC_GROUP = "NAME/ORGANIZATION/ETHNIC_GROUP"
ETHNIC_GROUP_OTHER = "NAME/ORGANIZATION/ETHNIC_GROUP/ETHNIC_GROUP_OTHER"
NATIONALITY = "NAME/ORGANIZATION/ETHNIC_GROUP/NATIONALITY"
FAMILY = "NAME/ORGANIZATION/FAMILY"
INTERNATIONAL_ORGANIZATION = "NAME/ORGANIZATION/INTERNATIONAL_ORGANIZATION"
ORGANIZATION_OTHER = "NAME/ORGANIZATION/ORGANIZATION_OTHER"
POLITICAL_ORGANIZATION = "NAME/ORGANIZATION/POLITICAL_ORGANIZATION"
CABINET = "NAME/ORGANIZATION/POLITICAL_ORGANIZATION/CABINET"
GOVERNMENT = "NAME/ORGANIZATION/POLITICAL_ORGANIZATION/GOVERNMENT"
MILITARY = "NAME/ORGANIZATION/POLITICAL_ORGANIZATION/MILITARY"
POLITICAL_ORGANIZATION_OTHER = (
    "NAME/ORGANIZATION/POLITICAL_ORGANIZATION/POLITICAL_ORGANIZATION_OTHER"
)
POLITICAL_PARTY = "NAME/ORGANIZATION/POLITICAL_ORGANIZATION/POLITICAL_PARTY"
SHOW_ORGANIZATION = "NAME/ORGANIZATION/SHOW_ORGANIZATION"
SPORTS_ORGANIZATION = "NAME/ORGANIZATION/SPORTS_ORGANIZATION"
PRO_SPORTS_ORGANIZATION = (
    "NAME/ORGANIZATION/SPORTS_ORGANIZATION/PRO_SPORTS_ORGANIZATION"
)
SPORTS_LEAGUE = "NAME/ORGANIZATION/SPORTS_ORGANIZATION/SPORTS_LEAGUE"
SPORTS_ORGANIZATION_OTHER = (
    "NAME/ORGANIZATION/SPORTS_ORGANIZATION/SPORTS_ORGANIZATION_OTHER"
)
PERSON = "NAME/PERSON"
PRODUCT = "NAME/PRODUCT"
ART = "NAME/PRODUCT/ART"
ART_OTHER = "NAME/PRODUCT/ART/ART_OTHER"
BOOK = "NAME/PRODUCT/ART/BOOK"
BROADCAST_PROGRAM = "NAME/PRODUCT/ART/BROADCAST_PROGRAM"
MOVIE = "NAME/PRODUCT/ART/MOVIE"
MUSIC = "NAME/PRODUCT/ART/MUSIC"
PICTURE = "NAME/PRODUCT/ART/PICTURE"
SHOW = "NAME/PRODUCT/ART/SHOW"
AWARD = "NAME/PRODUCT/AWARD"
CHARACTER = "NAME/PRODUCT/CHARACTER"
CLASS = "NAME/PRODUCT/CLASS"
CLOTHING = "NAME/PRODUCT/CLOTHING"
DECORATION = "NAME/PRODUCT/DECORATION"
DOCTRINE_METHOD = "NAME/PRODUCT/DOCTRINE_METHOD"
ACADEMIC = "NAME/PRODUCT/DOCTRINE_METHOD/ACADEMIC"
CULTURE = "NAME/PRODUCT/DOCTRINE_METHOD/CULTURE"
DOCTRINE_METHOD_OTHER = "NAME/PRODUCT/DOCTRINE_METHOD/DOCTRINE_METHOD_OTHER"
MOVEMENT = "NAME/PRODUCT/DOCTRINE_METHOD/MOVEMENT"
PLAN = "NAME/PRODUCT/DOCTRINE_METHOD/PLAN"
RELIGION = "NAME/PRODUCT/DOCTRINE_METHOD/RELIGION"
SPORT = "NAME/PRODUCT/DOCTRINE_METHOD/SPORT"
STYLE = "NAME/PRODUCT/DOCTRINE_METHOD/STYLE"
THEORY = "NAME/PRODUCT/DOCTRINE_METHOD/THEORY"
DRUG = "NAME/PRODUCT/DRUG"
FOOD = "NAME/PRODUCT/FOOD"
DISH = "NAME/PRODUCT/FOOD/DISH"
FOOD_OTHER = "NAME/PRODUCT/FOOD/FOOD_OTHER"
ID_NUMBER = "NAME/PRODUCT/ID_NUMBER"
LANGUAGE = "NAME/PRODUCT/LANGUAGE"
LANGUAGE_OTHER = "NAME/PRODUCT/LANGUAGE/LANGUAGE_OTHER"
NATIONAL_LANGUAGE = "NAME/PRODUCT/LANGUAGE/NATIONAL_LANGUAGE"
MATERIAL = "NAME/PRODUCT/MATERIAL"
MONEY_FORM = "NAME/PRODUCT/MONEY_FORM"
OFFENCE = "NAME/PRODUCT/OFFENCE"
PRINTING = "NAME/PRODUCT/PRINTING"
MAGAZINE = "NAME/PRODUCT/PRINTING/MAGAZINE"
NEWSPAPER = "NAME/PRODUCT/PRINTING/NEWSPAPER"
PRINTING_OTHER = "NAME/PRODUCT/PRINTING/PRINTING_OTHER"
PRODUCT_OTHER = "NAME/PRODUCT/PRODUCT_OTHER"
RULE = "NAME/PRODUCT/RULE"
LAW = "NAME/PRODUCT/RULE/LAW"
RULE_OTHER = "NAME/PRODUCT/RULE/RULE_OTHER"
TREATY = "NAME/PRODUCT/RULE/TREATY"
SERVICE = "NAME/PRODUCT/SERVICE"
STOCK = "NAME/PRODUCT/STOCK"
TITLE = "NAME/PRODUCT/TITLE"
POSITION_VOCATION = "NAME/PRODUCT/TITLE/POSITION_VOCATION"
TITLE_OTHER = "NAME/PRODUCT/TITLE/TITLE_OTHER"
UNIT = "NAME/PRODUCT/UNIT"
CURRENCY = "NAME/PRODUCT/UNIT/CURRENCY"
UNIT_OTHER = "NAME/PRODUCT/UNIT/UNIT_OTHER"
VEHICLE = "NAME/PRODUCT/VEHICLE"
AIRCRAFT = "NAME/PRODUCT/VEHICLE/AIRCRAFT"
CAR = "NAME/PRODUCT/VEHICLE/CAR"
SHIP = "NAME/PRODUCT/VEHICLE/SHIP"
SPACESHIP = "NAME/PRODUCT/VEHICLE/SPACESHIP"
TRAIN = "NAME/PRODUCT/VEHICLE/TRAIN"
VEHICLE_OTHER = "NAME/PRODUCT/VEHICLE/VEHICLE_OTHER"
WEAPON = "NAME/PRODUCT/WEAPON"
NUMEX = "NUMEX"
AGE = "NUMEX/AGE"
COUNTX = "NUMEX/COUNTX"
COUNTX_OTHER = "NUMEX/COUNTX/COUNTX_OTHER"
N_EVENT = "NUMEX/COUNTX/N_EVENT"
N_FACILITY = "NUMEX/COUNTX/N_FACILITY"
N_LOCATION = "NUMEX/COUNTX/N_LOCATION"
N_COUNTRY = "NUMEX/COUNTX/N_LOCATION/N_COUNTRY"
N_LOCATION_OTHER = "NUMEX/COUNTX/N_LOCATION/N_LOCATION_OTHER"
N_NATURAL_OBJECT = "NUMEX/COUNTX/N_NATURAL_OBJECT"
N_ANIMAL = "NUMEX/COUNTX/N_NATURAL_OBJECT/N_ANIMAL"
N_FLORA = "NUMEX/COUNTX/N_NATURAL_OBJECT/N_FLORA"
N_NATURAL_OBJECT_OTHER = "NUMEX/COUNTX/N_NATURAL_OBJECT/N_NATURAL_OBJECT_OTHER"
N_ORGANIZATION = "NUMEX/COUNTX/N_ORGANIZATION"
N_PERSON = "NUMEX/COUNTX/N_PERSON"
N_PRODUCT = "NUMEX/COUNTX/N_PRODUCT"
FREQUENCY = "NUMEX/FREQUENCY"
LATITUDE_LONGTITUDE = "NUMEX/LATITUDE_LONGTITUDE"
MEASUREMENT = "NUMEX/MEASUREMENT"
CALORIE = "NUMEX/MEASUREMENT/CALORIE"
INTENSITY = "NUMEX/MEASUREMENT/INTENSITY"
MEASUREMENT_OTHER = "NUMEX/MEASUREMENT/MEASUREMENT_OTHER"
PHYSICAL_EXTENT = "NUMEX/MEASUREMENT/PHYSICAL_EXTENT"
SEISMIC_INTENSITY = "NUMEX/MEASUREMENT/SEISMIC_INTENSITY"
SEISMIC_MAGNITUDE = "NUMEX/MEASUREMENT/SEISMIC_MAGNITUDE"
SPACE = "NUMEX/MEASUREMENT/SPACE"
SPEED = "NUMEX/MEASUREMENT/SPEED"
TEMPERATURE = "NUMEX/MEASUREMENT/TEMPERATURE"
VOLUME = "NUMEX/MEASUREMENT/VOLUME"
WEIGHT = "NUMEX/MEASUREMENT/WEIGHT"
MONEY = "NUMEX/MONEY"
MULTIPLICATION = "NUMEX/MULTIPLICATION"
NUMEX_OTHER = "NUMEX/NUMEX_OTHER"
ORDINAL_NUMBER = "NUMEX/ORDINAL_NUMBER"
PERCENT = "NUMEX/PERCENT"
POINT = "NUMEX/POINT"
RANK = "NUMEX/RANK"
SCHOOL_AGE = "NUMEX/SCHOOL_AGE"
STOCK_INDEX = "NUMEX/STOCK_INDEX"
TIME_TOP = "TIME_TOP"
PERIODX = "TIME_TOP/PERIODX"
PERIODX_OTHER = "TIME_TOP/PERIODX/PERIODX_OTHER"
PERIOD_DAY = "TIME_TOP/PERIODX/PERIOD_DAY"
PERIOD_MONTH = "TIME_TOP/PERIODX/PERIOD_MONTH"
PERIOD_TIME = "TIME_TOP/PERIODX/PERIOD_TIME"
PERIOD_WEEK = "TIME_TOP/PERIODX/PERIOD_WEEK"
PERIOD_YEAR = "TIME_TOP/PERIODX/PERIOD_YEAR"
TIMEX = "TIME_TOP/TIMEX"
DATE = "TIME_TOP/TIMEX/DATE"
DAY_OF_WEEK = "TIME_TOP/TIMEX/DAY_OF_WEEK"
ERA = "TIME_TOP/TIMEX/ERA"
TIME = "TIME_TOP/TIMEX/TIME"
TIMEX_OTHER = "TIME_TOP/TIMEX/TIMEX_OTHER"
TIME_TOP_OTHER = "TIME_TOP/TIME_TOP_OTHER"

ALL_LABELS = [
    NAME,
    COLOR,
    COLOR_OTHER,
    NATURE_COLOR,
    DISEASE,
    ANIMAL_DISEASE,
    DISEASE_OTHER,
    EVENT,
    EVENT_OTHER,
    INCIDENT,
    INCIDENT_OTHER,
    WAR,
    NATURAL_PHENOMENON,
    EARTHQUAKE,
    NATURAL_DISASTER,
    NATURAL_PHENOMENON_OTHER,
    OCCASION,
    CONFERENCE,
    GAME,
    OCCASION_OTHER,
    RELIGIOUS_FESTIVAL,
    FACILITY,
    ARCHAEOLOGICAL_PLACE,
    ARCHAEOLOGICAL_PLACE_OTHER,
    TUMULUS,
    FACILITY_OTHER,
    FACILITY_PART,
    GOE,
    AIRPORT,
    AMUSEMENT_PARK,
    CAR_STOP,
    GOE_OTHER,
    MARKET,
    MUSEUM,
    PARK,
    PORT,
    PUBLIC_INSTITUTION,
    RESEARCH_INSTITUTE,
    SCHOOL,
    SPORTS_FACILITY,
    STATION,
    THEATER,
    WORSHIP_PLACE,
    ZOO,
    LINE,
    BRIDGE,
    CANAL,
    LINE_OTHER,
    RAILROAD,
    ROAD,
    TUNNEL,
    WATER_ROUTE,
    GOD,
    LOCATION,
    ADDRESS,
    ADDRESS_OTHER,
    EMAIL,
    PHONE_NUMBER,
    POSTAL_ADDRESS,
    URL,
    ASTRAL_BODY,
    ASTRAL_BODY_OTHER,
    CONSTELLATION,
    PLANET,
    STAR,
    GEOLOGICAL_REGION,
    BAY,
    GEOLOGICAL_REGION_OTHER,
    ISLAND,
    LAKE,
    MOUNTAIN,
    RIVER,
    SEA,
    GPE,
    CITY,
    COUNTRY,
    COUNTY,
    GPE_OTHER,
    PROVINCE,
    LOCATION_OTHER,
    REGION,
    CONTINENTAL_REGION,
    DOMESTIC_REGION,
    REGION_OTHER,
    SPA,
    NAME_OTHER,
    NATURAL_OBJECT,
    COMPOUND,
    ELEMENT,
    LIVING_THING,
    AMPHIBIA,
    BIRD,
    FISH,
    FLORA,
    FUNGUS,
    INSECT,
    LIVING_THING_OTHER,
    MAMMAL,
    MOLLUSC_ARTHROPOD,
    REPTILE,
    LIVING_THING_PART,
    ANIMAL_PART,
    FLORA_PART,
    LIVING_THING_PART_OTHER,
    MINERAL,
    NATURAL_OBJECT_OTHER,
    ORGANIZATION,
    CORPORATION,
    COMPANY,
    COMPANY_GROUP,
    CORPORATION_OTHER,
    ETHNIC_GROUP,
    ETHNIC_GROUP_OTHER,
    NATIONALITY,
    FAMILY,
    INTERNATIONAL_ORGANIZATION,
    ORGANIZATION_OTHER,
    POLITICAL_ORGANIZATION,
    CABINET,
    GOVERNMENT,
    MILITARY,
    POLITICAL_ORGANIZATION_OTHER,
    POLITICAL_PARTY,
    SHOW_ORGANIZATION,
    SPORTS_ORGANIZATION,
    PRO_SPORTS_ORGANIZATION,
    SPORTS_LEAGUE,
    SPORTS_ORGANIZATION_OTHER,
    PERSON,
    PRODUCT,
    ART,
    ART_OTHER,
    BOOK,
    BROADCAST_PROGRAM,
    MOVIE,
    MUSIC,
    PICTURE,
    SHOW,
    AWARD,
    CHARACTER,
    CLASS,
    CLOTHING,
    DECORATION,
    DOCTRINE_METHOD,
    ACADEMIC,
    CULTURE,
    DOCTRINE_METHOD_OTHER,
    MOVEMENT,
    PLAN,
    RELIGION,
    SPORT,
    STYLE,
    THEORY,
    DRUG,
    FOOD,
    DISH,
    FOOD_OTHER,
    ID_NUMBER,
    LANGUAGE,
    LANGUAGE_OTHER,
    NATIONAL_LANGUAGE,
    MATERIAL,
    MONEY_FORM,
    OFFENCE,
    PRINTING,
    MAGAZINE,
    NEWSPAPER,
    PRINTING_OTHER,
    PRODUCT_OTHER,
    RULE,
    LAW,
    RULE_OTHER,
    TREATY,
    SERVICE,
    STOCK,
    TITLE,
    POSITION_VOCATION,
    TITLE_OTHER,
    UNIT,
    CURRENCY,
    UNIT_OTHER,
    VEHICLE,
    AIRCRAFT,
    CAR,
    SHIP,
    SPACESHIP,
    TRAIN,
    VEHICLE_OTHER,
    WEAPON,
    NUMEX,
    AGE,
    COUNTX,
    COUNTX_OTHER,
    N_EVENT,
    N_FACILITY,
    N_LOCATION,
    N_COUNTRY,
    N_LOCATION_OTHER,
    N_NATURAL_OBJECT,
    N_ANIMAL,
    N_FLORA,
    N_NATURAL_OBJECT_OTHER,
    N_ORGANIZATION,
    N_PERSON,
    N_PRODUCT,
    FREQUENCY,
    LATITUDE_LONGTITUDE,
    MEASUREMENT,
    CALORIE,
    INTENSITY,
    MEASUREMENT_OTHER,
    PHYSICAL_EXTENT,
    SEISMIC_INTENSITY,
    SEISMIC_MAGNITUDE,
    SPACE,
    SPEED,
    TEMPERATURE,
    VOLUME,
    WEIGHT,
    MONEY,
    MULTIPLICATION,
    NUMEX_OTHER,
    ORDINAL_NUMBER,
    PERCENT,
    POINT,
    RANK,
    SCHOOL_AGE,
    STOCK_INDEX,
    TIME_TOP,
    PERIODX,
    PERIODX_OTHER,
    PERIOD_DAY,
    PERIOD_MONTH,
    PERIOD_TIME,
    PERIOD_WEEK,
    PERIOD_YEAR,
    TIMEX,
    DATE,
    DAY_OF_WEEK,
    ERA,
    TIME,
    TIMEX_OTHER,
    TIME_TOP_OTHER,
]
